@@ -5,7 +5,7 @@ __all__ = [
     'get_option', 'set_option', 'reset_option',
     'get_printoptions', 'set_printoptions',
     'get_parseoptions', 'set_parseoptions',
-    'Jp2k', 'Tiff2Jp2k',
+    'Jp2k', 'Jp2kr', 'Tiff2Jp2k',
 ]
 
 # Local imports
@@ -13,7 +13,7 @@ from glymur import version
 from .options import (get_option, set_option, reset_option,
                       get_printoptions, set_printoptions,
                       get_parseoptions, set_parseoptions)
-from .jp2k import Jp2k
+from .jp2k import Jp2k, Jp2kr
 from .tiff import Tiff2Jp2k
 from . import data
 
