@@ -1,6 +1,7 @@
 """
 Tests for general glymur functionality.
 """
+
 # Standard library imports ...
 import collections
 import datetime
@@ -16,6 +17,7 @@ import warnings
 # Third party library imports ...
 from lxml import etree as ET
 import numpy as np
+import skimage
 
 # Local imports
 import glymur
@@ -29,17 +31,16 @@ from . import fixtures
 
 
 @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
-@unittest.skipIf(glymur.version.openjpeg_version < '2.4.0',
-                 "Requires as least v2.4.0")
+@unittest.skipIf(glymur.version.openjpeg_version < "2.4.0", "Requires as least v2.4.0")  # noqa : E501
 class TestJp2k(fixtures.TestCommon):
     """These tests should be run by just about all configuration."""
 
     def setUp(self):
         super().setUp()
-        glymur.reset_option('all')
+        glymur.reset_option("all")
 
     @unittest.skipIf(
-        glymur.version.openjpeg_version < '2.5.0', "Requires as least v2.5.0"
+        glymur.version.openjpeg_version < "2.5.0", "Requires as least v2.5.0"
     )
     def test_read_htj2k(self):
         """
@@ -47,7 +48,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  The size of the image read is verified.
         """
-        path = ir.files('tests.data').joinpath('oj-ht-byte.jph')
+        path = ir.files("tests.data").joinpath("oj-ht-byte.jph")
         j = Jp2k(path)
         d = j[:]
         self.assertEqual(d.shape, (20, 20))
@@ -59,7 +60,7 @@ class TestJp2k(fixtures.TestCommon):
         Expected response:  the representation is verified
         """
         j = Jp2k(self.j2kfile)
-        self.assertRegex(repr(j), 'glymur.Jp2k(.*?)')
+        self.assertRegex(repr(j), "glymur.Jp2k(.*?)")
 
     def test_write_using_slicing(self):
         """
@@ -67,7 +68,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected results:  no errors, data matches
         """
-        expected = fixtures.skimage.data.astronaut()
+        expected = skimage.data.astronaut()
 
         j1 = Jp2k(self.temp_jp2_filename)
         j1[:] = expected
@@ -101,7 +102,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.uint16
         """
-        path = ir.files('tests.data').joinpath('uint16.j2k')
+        path = ir.files("tests.data").joinpath("uint16.j2k")
         j = Jp2k(path)
         self.assertEqual(j.dtype, np.uint16)
 
@@ -122,7 +123,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.int8
         """
-        path = ir.files('tests.data').joinpath('p0_03.j2k')
+        path = ir.files("tests.data").joinpath("p0_03.j2k")
         j = Jp2k(path)
         self.assertEqual(j.dtype, np.int8)
 
@@ -132,7 +133,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  TypeError when accessing the dtype property.
         """
-        path = ir.files('tests.data').joinpath('issue392.jp2')
+        path = ir.files("tests.data").joinpath("issue392.jp2")
 
         with warnings.catch_warnings():
             # There's a warning due to an unrecognized colorspace.  Don't care
@@ -167,7 +168,7 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the ndim attribute/property is 2
         """
-        path = ir.files('tests.data').joinpath('p0_02.j2k')
+        path = ir.files("tests.data").joinpath("p0_02.j2k")
         j = Jp2k(path)
         self.assertEqual(j.ndim, 2)
 
@@ -178,7 +179,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESPONSE: The image is a list of arrays of unequal size.
         """
-        path = ir.files('tests.data').joinpath('p0_06.j2k')
+        path = ir.files("tests.data").joinpath("p0_06.j2k")
         d = Jp2k(path).read_bands()
 
         actual = [band.shape for band in d]
@@ -248,13 +249,12 @@ class TestJp2k(fixtures.TestCommon):
 
         # Rewrap the J2K file to reorder the components
         boxes = [
-            glymur.jp2box.JPEG2000SignatureBox(),
-            glymur.jp2box.FileTypeBox()
+            glymur.jp2box.JPEG2000SignatureBox(), glymur.jp2box.FileTypeBox()
         ]
         jp2h = glymur.jp2box.JP2HeaderBox()
         jp2h.box = [
             glymur.jp2box.ImageHeaderBox(height, width, num_components=ncomps),
-            glymur.jp2box.ColourSpecificationBox(colorspace=glymur.core.SRGB)
+            glymur.jp2box.ColourSpecificationBox(colorspace=glymur.core.SRGB),
         ]
 
         channel_type = [COLOR, COLOR, COLOR]
@@ -285,8 +285,8 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  RuntimeError
         """
         # copy nemo.jp2 but change the SIZ segment to have differing subsamples
-        with open(self.temp_jp2_filename, mode='wb') as ofile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as ofile:
+            with open(self.jp2file, "rb") as ifile:
                 # Copy up until codestream box.
                 ofile.write(ifile.read(77))
 
@@ -308,20 +308,17 @@ class TestJp2k(fixtures.TestCommon):
                 j[:]
 
     def test_shape_jp2(self):
-        """verify shape attribute for JP2 file
-        """
+        """verify shape attribute for JP2 file"""
         jp2 = Jp2k(self.jp2file)
         self.assertEqual(jp2.shape, (1456, 2592, 3))
 
     def test_shape_3_channel_j2k(self):
-        """verify shape attribute for J2K file
-        """
+        """verify shape attribute for J2K file"""
         j2k = Jp2k(self.j2kfile)
         self.assertEqual(j2k.shape, (800, 480, 3))
 
     def test_shape_jpx_jp2(self):
-        """verify shape attribute for JPX file with JP2 compatibility
-        """
+        """verify shape attribute for JPX file with JP2 compatibility"""
         jpx = Jp2k(self.jpxfile)
         self.assertEqual(jpx.shape, (1024, 1024, 3))
 
@@ -378,7 +375,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  RuntimeError
         """
-        path = ir.files('tests.data').joinpath('nemo.txt')
+        path = ir.files("tests.data").joinpath("nemo.txt")
         with self.assertRaises(InvalidJp2kError):
             Jp2k(path)
 
@@ -390,10 +387,10 @@ class TestJp2k(fixtures.TestCommon):
         c = jp2.get_codestream(header_only=False)
 
         # SOC
-        self.assertEqual(c.segment[0].marker_id, 'SOC')
+        self.assertEqual(c.segment[0].marker_id, "SOC")
 
         # SIZ
-        self.assertEqual(c.segment[1].marker_id, 'SIZ')
+        self.assertEqual(c.segment[1].marker_id, "SIZ")
         self.assertEqual(c.segment[1].rsiz, 0)
         self.assertEqual(c.segment[1].xsiz, 2592)
         self.assertEqual(c.segment[1].ysiz, 1456)
@@ -409,7 +406,7 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(c.segment[1].xrsiz, (1, 1, 1))
         self.assertEqual(c.segment[1].yrsiz, (1, 1, 1))
 
-        self.assertEqual(c.segment[2].marker_id, 'COD')
+        self.assertEqual(c.segment[2].marker_id, "COD")
         self.assertEqual(c.segment[2].offset, 136)
         self.assertEqual(c.segment[2].length, 12)
         self.assertEqual(c.segment[2].scod, 0)
@@ -421,7 +418,7 @@ class TestJp2k(fixtures.TestCommon):
             c.segment[2].precinct_size, np.array(((32768, 32768)))
         )
 
-        self.assertEqual(c.segment[3].marker_id, 'QCD')
+        self.assertEqual(c.segment[3].marker_id, "QCD")
         self.assertEqual(c.segment[3].offset, 150)
         self.assertEqual(c.segment[3].length, 7)
         self.assertEqual(c.segment[3].sqcd, 64)
@@ -429,12 +426,11 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(c.segment[3].exponent, [8, 9, 9, 10])
         self.assertEqual(c.segment[3].guard_bits, 2)
 
-        self.assertEqual(c.segment[4].marker_id, 'CME')
+        self.assertEqual(c.segment[4].marker_id, "CME")
         self.assertEqual(c.segment[4].rcme, 1)
-        self.assertEqual(c.segment[4].ccme,
-                         b'Created by OpenJPEG version 2.0.0')
+        self.assertEqual(c.segment[4].ccme, b"Created by OpenJPEG version 2.0.0")  # noqa : E501
 
-        self.assertEqual(c.segment[5].marker_id, 'SOT')
+        self.assertEqual(c.segment[5].marker_id, "SOT")
         self.assertEqual(c.segment[5].offset, 198)
         self.assertEqual(c.segment[5].length, 10)
         self.assertEqual(c.segment[5].isot, 0)
@@ -442,19 +438,17 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(c.segment[5].tpsot, 0)
         self.assertEqual(c.segment[5].tnsot, 1)
 
-        self.assertEqual(c.segment[6].marker_id, 'COC')
+        self.assertEqual(c.segment[6].marker_id, "COC")
         self.assertEqual(c.segment[6].offset, 210)
         self.assertEqual(c.segment[6].length, 9)
         self.assertEqual(c.segment[6].ccoc, 1)
-        np.testing.assert_array_equal(c.segment[6].scoc,
-                                      np.array([0]))
-        np.testing.assert_array_equal(c.segment[6].spcoc,
-                                      np.array([1, 4, 4, 0, 1]))
+        np.testing.assert_array_equal(c.segment[6].scoc, np.array([0]))
+        np.testing.assert_array_equal(c.segment[6].spcoc, np.array([1, 4, 4, 0, 1]))  # noqa : E501
         np.testing.assert_array_equal(
             c.segment[6].precinct_size, np.array(((32768, 32768)))
         )
 
-        self.assertEqual(c.segment[7].marker_id, 'QCC')
+        self.assertEqual(c.segment[7].marker_id, "QCC")
         self.assertEqual(c.segment[7].offset, 221)
         self.assertEqual(c.segment[7].length, 8)
         self.assertEqual(c.segment[7].cqcc, 1)
@@ -463,20 +457,17 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(c.segment[7].exponent, [8, 9, 9, 10])
         self.assertEqual(c.segment[7].guard_bits, 2)
 
-        self.assertEqual(c.segment[8].marker_id, 'COC')
+        self.assertEqual(c.segment[8].marker_id, "COC")
         self.assertEqual(c.segment[8].offset, 231)
         self.assertEqual(c.segment[8].length, 9)
         self.assertEqual(c.segment[8].ccoc, 2)
-        np.testing.assert_array_equal(c.segment[8].scoc,
-                                      np.array([0]))
-        np.testing.assert_array_equal(c.segment[8].spcoc,
-                                      np.array([1, 4, 4, 0, 1]))
+        np.testing.assert_array_equal(c.segment[8].scoc, np.array([0]))
+        np.testing.assert_array_equal(c.segment[8].spcoc, np.array([1, 4, 4, 0, 1]))  # noqa : E501
         np.testing.assert_array_equal(
-            c.segment[8].precinct_size,
-            np.array(((32768, 32768)))
+            c.segment[8].precinct_size, np.array(((32768, 32768)))
         )
 
-        self.assertEqual(c.segment[9].marker_id, 'QCC')
+        self.assertEqual(c.segment[9].marker_id, "QCC")
         self.assertEqual(c.segment[9].offset, 242)
         self.assertEqual(c.segment[9].length, 8)
         self.assertEqual(c.segment[9].cqcc, 2)
@@ -485,9 +476,9 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(c.segment[9].exponent, [8, 9, 9, 10])
         self.assertEqual(c.segment[9].guard_bits, 2)
 
-        self.assertEqual(c.segment[10].marker_id, 'SOD')
+        self.assertEqual(c.segment[10].marker_id, "SOD")
 
-        self.assertEqual(c.segment[11].marker_id, 'EOC')
+        self.assertEqual(c.segment[11].marker_id, "EOC")
 
     def test_jp2_boxes(self):
         """Verify the boxes of a JP2 file.  Basic jp2 test."""
@@ -496,32 +487,32 @@ class TestJp2k(fixtures.TestCommon):
         # top-level boxes
         self.assertEqual(len(jp2k.box), 4)
 
-        self.assertEqual(jp2k.box[0].box_id, 'jP  ')
+        self.assertEqual(jp2k.box[0].box_id, "jP  ")
         self.assertEqual(jp2k.box[0].offset, 0)
         self.assertEqual(jp2k.box[0].length, 12)
-        self.assertEqual(jp2k.box[0].longname, 'JPEG 2000 Signature')
+        self.assertEqual(jp2k.box[0].longname, "JPEG 2000 Signature")
 
-        self.assertEqual(jp2k.box[1].box_id, 'ftyp')
+        self.assertEqual(jp2k.box[1].box_id, "ftyp")
         self.assertEqual(jp2k.box[1].offset, 12)
         self.assertEqual(jp2k.box[1].length, 20)
-        self.assertEqual(jp2k.box[1].longname, 'File Type')
+        self.assertEqual(jp2k.box[1].longname, "File Type")
 
-        self.assertEqual(jp2k.box[2].box_id, 'jp2h')
+        self.assertEqual(jp2k.box[2].box_id, "jp2h")
         self.assertEqual(jp2k.box[2].offset, 32)
         self.assertEqual(jp2k.box[2].length, 45)
-        self.assertEqual(jp2k.box[2].longname, 'JP2 Header')
+        self.assertEqual(jp2k.box[2].longname, "JP2 Header")
 
-        self.assertEqual(jp2k.box[3].box_id, 'jp2c')
+        self.assertEqual(jp2k.box[3].box_id, "jp2c")
         self.assertEqual(jp2k.box[3].offset, 77)
         self.assertEqual(jp2k.box[3].length, 1132296)
 
         # jp2h super box
         self.assertEqual(len(jp2k.box[2].box), 2)
 
-        self.assertEqual(jp2k.box[2].box[0].box_id, 'ihdr')
+        self.assertEqual(jp2k.box[2].box[0].box_id, "ihdr")
         self.assertEqual(jp2k.box[2].box[0].offset, 40)
         self.assertEqual(jp2k.box[2].box[0].length, 22)
-        self.assertEqual(jp2k.box[2].box[0].longname, 'Image Header')
+        self.assertEqual(jp2k.box[2].box[0].longname, "Image Header")
         self.assertEqual(jp2k.box[2].box[0].height, 1456)
         self.assertEqual(jp2k.box[2].box[0].width, 2592)
         self.assertEqual(jp2k.box[2].box[0].num_components, 3)
@@ -531,10 +522,10 @@ class TestJp2k(fixtures.TestCommon):
         self.assertEqual(jp2k.box[2].box[0].colorspace_unknown, False)
         self.assertEqual(jp2k.box[2].box[0].ip_provided, False)
 
-        self.assertEqual(jp2k.box[2].box[1].box_id, 'colr')
+        self.assertEqual(jp2k.box[2].box[1].box_id, "colr")
         self.assertEqual(jp2k.box[2].box[1].offset, 62)
         self.assertEqual(jp2k.box[2].box[1].length, 15)
-        self.assertEqual(jp2k.box[2].box[1].longname, 'Colour Specification')
+        self.assertEqual(jp2k.box[2].box[1].longname, "Colour Specification")
         self.assertEqual(jp2k.box[2].box[1].precedence, 0)
         self.assertEqual(jp2k.box[2].box[1].approximation, 0)
         self.assertEqual(jp2k.box[2].box[1].colorspace, glymur.core.SRGB)
@@ -556,8 +547,8 @@ class TestJp2k(fixtures.TestCommon):
         """
         # Don't have such a file on hand, so we create one.  Copy our example
         # file, but making the codestream have a 64-bit XL field.
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as tfile:
+            with open(self.jp2file, "rb") as ifile:
                 # Everything up until the jp2c box.
                 write_buffer = ifile.read(77)
                 tfile.write(write_buffer)
@@ -566,9 +557,9 @@ class TestJp2k(fixtures.TestCommon):
                 # XL field.  The actual length of the jp2c box increased by 8
                 # (8 bytes for the XL field).
                 length = 1
-                typ = b'jp2c'
+                typ = b"jp2c"
                 xlen = 1132296 + 8
-                write_buffer = struct.pack('>I4sQ', int(length), typ, xlen)
+                write_buffer = struct.pack(">I4sQ", int(length), typ, xlen)
                 tfile.write(write_buffer)
 
                 # Get the rest of the input file (minus the 8 bytes for L and
@@ -580,7 +571,7 @@ class TestJp2k(fixtures.TestCommon):
 
             jp2k = Jp2k(tfile.name)
 
-            self.assertEqual(jp2k.box[3].box_id, 'jp2c')
+            self.assertEqual(jp2k.box[3].box_id, "jp2c")
             self.assertEqual(jp2k.box[3].offset, 77)
             self.assertEqual(jp2k.box[3].length, 1132296 + 8)
 
@@ -595,15 +586,15 @@ class TestJp2k(fixtures.TestCommon):
         # This should only happen in the last box of a JPEG 2000 file.
         # Our example image has its last box at byte 588458.
         baseline_jp2 = Jp2k(self.jp2file)
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as tfile:
+            with open(self.jp2file, "rb") as ifile:
                 # Everything up until the jp2c box.
                 write_buffer = ifile.read(588458)
                 tfile.write(write_buffer)
 
                 length = 0
-                typ = b'uuid'
-                write_buffer = struct.pack('>I4s', int(length), typ)
+                typ = b"uuid"
+                write_buffer = struct.pack(">I4s", int(length), typ)
                 tfile.write(write_buffer)
 
                 # Get the rest of the input file (minus the 8 bytes for L and
@@ -617,12 +608,9 @@ class TestJp2k(fixtures.TestCommon):
 
             # The top level boxes in each file should match.
             for j in range(len(baseline_jp2.box)):
-                self.assertEqual(new_jp2.box[j].box_id,
-                                 baseline_jp2.box[j].box_id)
-                self.assertEqual(new_jp2.box[j].offset,
-                                 baseline_jp2.box[j].offset)
-                self.assertEqual(new_jp2.box[j].length,
-                                 baseline_jp2.box[j].length)
+                self.assertEqual(new_jp2.box[j].box_id, baseline_jp2.box[j].box_id)  # noqa : E501
+                self.assertEqual(new_jp2.box[j].offset, baseline_jp2.box[j].offset)  # noqa : E501
+                self.assertEqual(new_jp2.box[j].length, baseline_jp2.box[j].length)  # noqa : E501
 
     @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
     def test_basic_jp2(self):
@@ -654,8 +642,8 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  The file is parsed without error.
         """
         # Must create the file.
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as tfile:
+            with open(self.jp2file, "rb") as ifile:
                 # Everything up until the jp2c box.
                 write_buffer = ifile.read(77)
                 tfile.write(write_buffer)
@@ -663,15 +651,21 @@ class TestJp2k(fixtures.TestCommon):
                 # Write the UINF superbox
                 # Length = 50, id is uinf.
                 uinf_len = 50
-                write_buffer = struct.pack('>I4s', int(uinf_len), b'uinf')
+                write_buffer = struct.pack(">I4s", int(uinf_len), b"uinf")
                 tfile.write(write_buffer)
 
                 # Write the ULST box.
                 # Length is 26, 1 UUID, hard code that UUID as zeros.
                 ulst_len = 26
                 write_buffer = struct.pack(
-                    '>I4sHIIII',
-                    ulst_len, b'ulst', int(1), int(0), int(0), int(0), int(0)
+                    ">I4sHIIII",
+                    ulst_len,
+                    b"ulst",
+                    int(1),
+                    int(0),
+                    int(0),
+                    int(0),
+                    int(0),
                 )
                 tfile.write(write_buffer)
 
@@ -680,11 +674,13 @@ class TestJp2k(fixtures.TestCommon):
                 # is the rest.
                 url_box_len = 16
                 write_buffer = struct.pack(
-                    '>I4sBBBB',
-                    url_box_len, b'url ', int(0), int(0), int(0), int(0)
+                    ">I4sBBBB",
+                    url_box_len,
+                    b"url ",
+                    int(0), int(0), int(0), int(0)
                 )
                 tfile.write(write_buffer)
-                write_buffer = struct.pack('>ssss', b'a', b'b', b'c', b'd')
+                write_buffer = struct.pack(">ssss", b"a", b"b", b"c", b"d")
                 tfile.write(write_buffer)
 
                 # Get the rest of the input file.
@@ -694,23 +690,23 @@ class TestJp2k(fixtures.TestCommon):
 
             jp2k = Jp2k(tfile.name)
 
-            self.assertEqual(jp2k.box[3].box_id, 'uinf')
+            self.assertEqual(jp2k.box[3].box_id, "uinf")
             self.assertEqual(jp2k.box[3].offset, 77)
             self.assertEqual(jp2k.box[3].length, uinf_len)
 
-            self.assertEqual(jp2k.box[3].box[0].box_id, 'ulst')
+            self.assertEqual(jp2k.box[3].box[0].box_id, "ulst")
             self.assertEqual(jp2k.box[3].box[0].offset, 85)
             self.assertEqual(jp2k.box[3].box[0].length, ulst_len)
             ulst = []
-            ulst.append(uuid.UUID('00000000-0000-0000-0000-000000000000'))
+            ulst.append(uuid.UUID("00000000-0000-0000-0000-000000000000"))
             self.assertEqual(jp2k.box[3].box[0].ulst, ulst)
 
-            self.assertEqual(jp2k.box[3].box[1].box_id, 'url ')
+            self.assertEqual(jp2k.box[3].box[1].box_id, "url ")
             self.assertEqual(jp2k.box[3].box[1].offset, 111)
             self.assertEqual(jp2k.box[3].box[1].length, url_box_len)
             self.assertEqual(jp2k.box[3].box[1].version, 0)
             self.assertEqual(jp2k.box[3].box[1].flag, (0, 0, 0))
-            self.assertEqual(jp2k.box[3].box[1].url, 'abcd')
+            self.assertEqual(jp2k.box[3].box[1].url, "abcd")
 
     def test_xml_with_trailing_nulls(self):
         """
@@ -720,18 +716,18 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  The xml box is parsed without issue and the original
         XML is recovered.
         """
-        with open(self.temp_jp2_filename, mode='wb') as tfile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as tfile:
+            with open(self.jp2file, "rb") as ifile:
                 # Everything up until the jp2c box.
                 write_buffer = ifile.read(77)
                 tfile.write(write_buffer)
 
                 # Write the xml box
                 # Length = 36, id is 'xml '.
-                write_buffer = struct.pack('>I4s', int(36), b'xml ')
+                write_buffer = struct.pack(">I4s", int(36), b"xml ")
                 tfile.write(write_buffer)
 
-                write_buffer = '<test>this is a test</test>' + chr(0)
+                write_buffer = "<test>this is a test</test>" + chr(0)
                 write_buffer = write_buffer.encode()
                 tfile.write(write_buffer)
 
@@ -742,11 +738,13 @@ class TestJp2k(fixtures.TestCommon):
 
             jp2k = Jp2k(tfile.name)
 
-            self.assertEqual(jp2k.box[3].box_id, 'xml ')
+            self.assertEqual(jp2k.box[3].box_id, "xml ")
             self.assertEqual(jp2k.box[3].offset, 77)
             self.assertEqual(jp2k.box[3].length, 36)
-            self.assertEqual(ET.tostring(jp2k.box[3].xml.getroot()),
-                             b'<test>this is a test</test>')
+            self.assertEqual(
+                ET.tostring(jp2k.box[3].xml.getroot()),
+                b"<test>this is a test</test>"
+            )
 
     @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
     def test_jpx_mult_codestreams_jp2_brand(self):
@@ -765,13 +763,13 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  The file is parsed without error and the zero-length
         segment is detected in the codestream.  No warning is issued.
         """
-        with open(self.temp_jp2_filename, mode='wb') as ofile:
-            with open(self.jp2file, 'rb') as ifile:
+        with open(self.temp_jp2_filename, mode="wb") as ofile:
+            with open(self.jp2file, "rb") as ifile:
                 # Copy up until codestream box.
                 ofile.write(ifile.read(77))
 
                 # Write the new codestream length (+4) and the box ID.
-                buffer = struct.pack('>I4s', 1132296 + 4, b'jp2c')
+                buffer = struct.pack(">I4s", 1132296 + 4, b"jp2c")
                 ofile.write(buffer)
 
                 # Copy up until the EOC marker.
@@ -779,7 +777,7 @@ class TestJp2k(fixtures.TestCommon):
                 ofile.write(ifile.read(1132286))
 
                 # Write the zero-length reserved segment.
-                buffer = struct.pack('>BBH', 0xff, 0x00, 0)
+                buffer = struct.pack(">BBH", 0xFF, 0x00, 0)
                 ofile.write(buffer)
 
                 # Write the EOC marker and be done with it.
@@ -787,7 +785,7 @@ class TestJp2k(fixtures.TestCommon):
                 ofile.flush()
 
         cstr = Jp2k(ofile.name).get_codestream(header_only=False)
-        self.assertEqual(cstr.segment[11].marker_id, '0xff00')
+        self.assertEqual(cstr.segment[11].marker_id, "0xff00")
         self.assertEqual(cstr.segment[11].length, 0)
 
     def test_psot_is_zero(self):
@@ -798,13 +796,13 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  The file should parse without error.  The SOT marker
         should be detected.
         """
-        with open(self.temp_j2k_filename, mode='wb') as ofile:
-            with open(self.j2kfile, 'rb') as ifile:
+        with open(self.temp_j2k_filename, mode="wb") as ofile:
+            with open(self.j2kfile, "rb") as ifile:
                 # Write up until the SOD segment.
                 ofile.write(ifile.read(164))
 
                 # Write a SOT box with Psot = 0
-                buffer = struct.pack('>HHHIBB', 0xff90, 10, 0, 0, 0, 1)
+                buffer = struct.pack(">HHHIBB", 0xFF90, 10, 0, 0, 0, 1)
                 ofile.write(buffer)
 
                 # Write the rest of it.
@@ -816,9 +814,9 @@ class TestJp2k(fixtures.TestCommon):
 
             # The codestream is valid, so we should be able to get the entire
             # codestream, so the last one is EOC.
-            self.assertEqual(codestream.segment[-3].marker_id, 'SOT')
-            self.assertEqual(codestream.segment[-2].marker_id, 'SOD')
-            self.assertEqual(codestream.segment[-1].marker_id, 'EOC')
+            self.assertEqual(codestream.segment[-3].marker_id, "SOT")
+            self.assertEqual(codestream.segment[-2].marker_id, "SOD")
+            self.assertEqual(codestream.segment[-1].marker_id, "EOC")
 
     def test_basic_icc_profile(self):
         """
@@ -829,55 +827,54 @@ class TestJp2k(fixtures.TestCommon):
         fp = BytesIO()
 
         # Write the colr box header.
-        buffer = struct.pack('>I4s', 557, b'colr')
-        buffer += struct.pack('>BBB', RESTRICTED_ICC_PROFILE, 2, 1)
+        buffer = struct.pack(">I4s", 557, b"colr")
+        buffer += struct.pack(">BBB", RESTRICTED_ICC_PROFILE, 2, 1)
 
-        buffer += struct.pack('>IIBB', 546, 0, 2, 32)
-        buffer += b'\x00' * 2 + b'scnr' + b'RGB ' + b'XYZ '
+        buffer += struct.pack(">IIBB", 546, 0, 2, 32)
+        buffer += b"\x00" * 2 + b"scnr" + b"RGB " + b"XYZ "
         # Need a date in bytes 24:36
-        buffer += struct.pack('>HHHHHH', 2001, 8, 30, 13, 32, 37)
-        buffer += 'acsp'.encode('utf-8')
-        buffer += b'\x00\x00\x00\x00'
-        buffer += b'\x00\x00\x00\x01'  # platform
-        buffer += 'KODA'.encode('utf-8')  # 48 - 52
-        buffer += 'ROMM'.encode('utf-8')  # Device Model
-        buffer += b'\x00' * 12
-        buffer += struct.pack('>III', 63190, 65536, 54061)  # 68 - 80
-        buffer += 'JPEG'.encode('utf-8')  # 80 - 84
-        buffer += b'\x00' * 44
+        buffer += struct.pack(">HHHHHH", 2001, 8, 30, 13, 32, 37)
+        buffer += "acsp".encode("utf-8")
+        buffer += b"\x00\x00\x00\x00"
+        buffer += b"\x00\x00\x00\x01"  # platform
+        buffer += "KODA".encode("utf-8")  # 48 - 52
+        buffer += "ROMM".encode("utf-8")  # Device Model
+        buffer += b"\x00" * 12
+        buffer += struct.pack(">III", 63190, 65536, 54061)  # 68 - 80
+        buffer += "JPEG".encode("utf-8")  # 80 - 84
+        buffer += b"\x00" * 44
         fp.write(buffer)
         fp.seek(8)
 
         box = glymur.jp2box.ColourSpecificationBox.parse(fp, 0, 557)
         profile = box.icc_profile_header
 
-        self.assertEqual(profile['Size'], 546)
-        self.assertEqual(profile['Preferred CMM Type'], 0)
-        self.assertEqual(profile['Version'], '2.2.0')
-        self.assertEqual(profile['Device Class'], 'input device profile')
-        self.assertEqual(profile['Color Space'], 'RGB')
-        self.assertEqual(profile['Datetime'],
-                         datetime.datetime(2001, 8, 30, 13, 32, 37))
-        self.assertEqual(profile['File Signature'], 'acsp')
-        self.assertEqual(profile['Platform'], 'unrecognized')
-        self.assertEqual(profile['Flags'],
-                         'embedded, can be used independently')
+        self.assertEqual(profile["Size"], 546)
+        self.assertEqual(profile["Preferred CMM Type"], 0)
+        self.assertEqual(profile["Version"], "2.2.0")
+        self.assertEqual(profile["Device Class"], "input device profile")
+        self.assertEqual(profile["Color Space"], "RGB")
+        self.assertEqual(
+            profile["Datetime"], datetime.datetime(2001, 8, 30, 13, 32, 37)
+        )
+        self.assertEqual(profile["File Signature"], "acsp")
+        self.assertEqual(profile["Platform"], "unrecognized")
+        self.assertEqual(profile["Flags"], "embedded, can be used independently")  # noqa : E501
 
-        self.assertEqual(profile['Device Manufacturer'], 'KODA')
-        self.assertEqual(profile['Device Model'], 'ROMM')
+        self.assertEqual(profile["Device Manufacturer"], "KODA")
+        self.assertEqual(profile["Device Model"], "ROMM")
 
-        self.assertEqual(profile['Device Attributes'],
-                         ('reflective, glossy, positive media polarity, '
-                          'color media'))
-        self.assertEqual(profile['Rendering Intent'], 'perceptual')
+        self.assertEqual(
+            profile["Device Attributes"],
+            ("reflective, glossy, positive media polarity, " "color media"),
+        )
+        self.assertEqual(profile["Rendering Intent"], "perceptual")
 
         np.testing.assert_almost_equal(
-            profile['Illuminant'],
-            (0.964203, 1.000000, 0.824905),
-            decimal=6
+            profile["Illuminant"], (0.964203, 1.000000, 0.824905), decimal=6
         )
 
-        self.assertEqual(profile['Creator'], 'JPEG')
+        self.assertEqual(profile["Creator"], "JPEG")
 
     @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
     def test_different_layers(self):
@@ -886,7 +883,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The 2nd image read in is not the same as the first.
         """
-        path = ir.files('tests.data').joinpath('p0_03.j2k')
+        path = ir.files("tests.data").joinpath("p0_03.j2k")
         j = Jp2k(path)
         d0 = j[:]
 
@@ -903,7 +900,7 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  RuntimeError when an invalid layer number is supplied
         """
         # There are 8 layers, so only values [0-7] are valid.
-        path = ir.files('tests.data').joinpath('p0_03.j2k')
+        path = ir.files("tests.data").joinpath("p0_03.j2k")
         j = Jp2k(path)
 
         with self.assertRaises(ValueError):
@@ -922,7 +919,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The default verbosity setting is False.
         """
-        path = ir.files('tests.data').joinpath('p0_03.j2k')
+        path = ir.files("tests.data").joinpath("p0_03.j2k")
         j = Jp2k(path)
 
         self.assertFalse(j.verbose)
@@ -933,7 +930,7 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The default layer property value is 0.
         """
-        path = ir.files('tests.data').joinpath('p0_03.j2k')
+        path = ir.files("tests.data").joinpath("p0_03.j2k")
         j = Jp2k(path)
 
         self.assertEqual(j.layer, 0)
@@ -945,14 +942,15 @@ class TestVersion(fixtures.TestCommon):
     version of openjpeg installed, or even if openjpeg is not installed,
     because we fully mock the openjpeg version.
     """
+
     def test_read_minimum_version(self):
         """
         Scenario:  we have openjpeg, but not the minimum supported version.
 
         Expected Result:  RuntimeError
         """
-        with patch('glymur.version.openjpeg_version_tuple', new=(2, 2, 9)):
-            with patch('glymur.version.openjpeg_version', new='2.2.9'):
+        with patch("glymur.version.openjpeg_version_tuple", new=(2, 2, 9)):
+            with patch("glymur.version.openjpeg_version", new="2.2.9"):
                 with self.assertRaises(RuntimeError):
                     glymur.Jp2k(self.jp2file)[:]
 
@@ -960,8 +958,8 @@ class TestVersion(fixtures.TestCommon):
         """
         Don't have openjpeg or openjp2 library?  Must error out.
         """
-        with patch('glymur.version.openjpeg_version_tuple', new=(0, 0, 0)):
-            with patch('glymur.version.openjpeg_version', new='0.0.0'):
+        with patch("glymur.version.openjpeg_version_tuple", new=(0, 0, 0)):
+            with patch("glymur.version.openjpeg_version", new="0.0.0"):
                 with self.assertRaises(RuntimeError):
                     with warnings.catch_warnings():
                         # Suppress a deprecation warning for raw read method.
@@ -975,8 +973,8 @@ class TestVersion(fixtures.TestCommon):
         Don't have openjp2 library?  Must error out.
         """
         exp_error = RuntimeError
-        with patch('glymur.version.openjpeg_version_tuple', new=(1, 5, 0)):
-            with patch('glymur.version.openjpeg_version', new='1.5.0'):
+        with patch("glymur.version.openjpeg_version_tuple", new=(1, 5, 0)):
+            with patch("glymur.version.openjpeg_version", new="1.5.0"):
                 with self.assertRaises(exp_error):
                     glymur.Jp2k(self.jp2file).read_bands()
 
@@ -985,6 +983,7 @@ class TestComponent(unittest.TestCase):
     """
     Test how a component's precision translates into a datatype.
     """
+
     @classmethod
     def setUpClass(cls):
         cls.jp2file = glymur.data.nemo()
@@ -998,7 +997,7 @@ class TestComponent(unittest.TestCase):
         j = Jp2k(self.jp2file)
 
         # Fake a data structure that resembles the openjpeg component.
-        Component = collections.namedtuple('Component', ['prec', 'sgnd'])
+        Component = collections.namedtuple("Component", ["prec", "sgnd"])
         c = Component(prec=7, sgnd=True)
         dtype = j._component2dtype(c)
         self.assertEqual(dtype, np.int8)
@@ -1012,7 +1011,7 @@ class TestComponent(unittest.TestCase):
         j = Jp2k(self.jp2file)
 
         # Fake a data structure that resembles the openjpeg component.
-        Component = collections.namedtuple('Component', ['prec', 'sgnd'])
+        Component = collections.namedtuple("Component", ["prec", "sgnd"])
         c = Component(prec=15, sgnd=True)
         dtype = j._component2dtype(c)
         self.assertEqual(dtype, np.int16)
@@ -1026,7 +1025,7 @@ class TestComponent(unittest.TestCase):
         j = Jp2k(self.jp2file)
 
         # Fake a data structure that resembles the openjpeg component.
-        Component = collections.namedtuple('Component', ['prec', 'sgnd'])
+        Component = collections.namedtuple("Component", ["prec", "sgnd"])
         c = Component(prec=17, sgnd=True)
         with self.assertRaises(ValueError):
             j._component2dtype(c)
@@ -1036,13 +1035,14 @@ class TestParsing(unittest.TestCase):
     """
     Tests for verifying how parsing may be altered.
     """
+
     def setUp(self):
         self.jp2file = glymur.data.nemo()
         # Reset parseoptions for every test.
-        glymur.set_option('parse.full_codestream', False)
+        glymur.set_option("parse.full_codestream", False)
 
     def tearDown(self):
-        glymur.set_option('parse.full_codestream', False)
+        glymur.set_option("parse.full_codestream", False)
 
     def test_main_header(self):
         """verify that the main header isn't loaded during normal parsing"""
