@@ -50,6 +50,7 @@ class TestSuite(unittest.TestCase):
         j2k.decoded_components = 0
         actual = j2k[:]
 
+        self.assertEqual(j2k.decoded_components, [0])
         np.testing.assert_array_equal(actual, expected)
 
         # restore the original configuration
@@ -149,7 +150,6 @@ class TestSuite(unittest.TestCase):
             with warnings.catch_warnings():
                 warnings.simplefilter('error')
                 j2k.decoded_components = -1
-                j2k[:]
 
     def test_same_component_several_times(self):
         """
