@@ -12,6 +12,7 @@ from uuid import UUID
 import warnings
 
 # 3rd party library imports
+from PIL import Image
 import numpy as np
 import skimage
 
@@ -43,6 +44,7 @@ class TestSuite(fixtures.TestCommon):
         cls.ycbcr_bg = root.joinpath('ycbcr_bg.tif')
         cls.ycbcr_stripped = root.joinpath('ycbcr_stripped.tif')
         cls.stripped = root.joinpath('stripped.tif')
+        cls.moon63 = root.joinpath('moon63.tif')
 
         test_tiff_dir = tempfile.mkdtemp()
         cls.test_tiff_path = pathlib.Path(test_tiff_dir)
@@ -192,6 +194,17 @@ class TestSuite(fixtures.TestCommon):
 
         cls.exif = path
 
+    def _imread(self, path, mode=None):
+
+        with Image.open(path) as img:
+
+            if mode is not None:
+                img = img.convert(mode)
+
+            imagedata = np.array(img)
+
+        return imagedata
+
     def test_smoke(self):
         """
         SCENARIO:  Convert TIFF file to JP2
@@ -354,7 +367,7 @@ class TestSuite(fixtures.TestCommon):
             j.layer = layer
             d[layer] = j[:]
 
-        truth = skimage.io.imread(self.moon)
+        truth = self._imread(self.moon)
 
         with warnings.catch_warnings():
             # MSE is zero for that first image, resulting in a divide-by-zero
@@ -393,7 +406,7 @@ class TestSuite(fixtures.TestCommon):
             j.layer = layer
             d[layer] = j[:]
 
-        truth = skimage.io.imread(self.moon)
+        truth = self._imread(self.moon)
 
         with warnings.catch_warnings():
             # MSE is zero for that first image, resulting in a divide-by-zero
@@ -631,9 +644,7 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(
-            self.moon3_partial_last_strip, plugin='pil'
-        )
+        expected = self._imread(self.moon3_partial_last_strip)
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -659,9 +670,8 @@ class TestSuite(fixtures.TestCommon):
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
 
-        expected = skimage.io.imread(
-            self.moon3_partial_last_strip, plugin='pil'
-        )
+        expected = self._imread(self.moon3_partial_last_strip)
+
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -812,7 +822,7 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(self.ycbcr_stripped, plugin='pil')
+        expected = self._imread(self.ycbcr_stripped)
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -835,7 +845,7 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(self.ycbcr_bg, plugin='pil')
+        expected = self._imread(self.ycbcr_bg)
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -882,9 +892,8 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(
-            self.astronaut_ycbcr_jpeg_tiled, plugin='pil'
-        )
+        expected = self._imread(self.astronaut_ycbcr_jpeg_tiled)
+
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -908,9 +917,7 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(
-            self.astronaut_ycbcr_jpeg_tiled, plugin='pil'
-        )
+        expected = self._imread(self.astronaut_ycbcr_jpeg_tiled)
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -933,9 +940,7 @@ class TestSuite(fixtures.TestCommon):
 
         jp2 = Jp2k(self.temp_jp2_filename)
         actual = jp2[:]
-        expected = skimage.io.imread(
-            self.astronaut_ycbcr_jpeg_tiled, plugin='pil'
-        )
+        expected = self._imread(self.astronaut_ycbcr_jpeg_tiled)
         np.testing.assert_array_equal(actual, expected)
 
         c = jp2.get_codestream()
@@ -1835,9 +1840,7 @@ class TestSuite(fixtures.TestCommon):
         # Read in the image (as expected on little-endian), flip it
         # around, prepend an alpha layer, then get rid of the last layer
         # to simulate what would have happened on big-endian.
-        expected = skimage.io.imread(
-            self.astronaut_ycbcr_jpeg_tiled, plugin='pil'
-        )
+        expected = self._imread(self.astronaut_ycbcr_jpeg_tiled)
         h, w, _ = expected.shape
         expected = np.flip(expected, axis=2)
         A = np.ones((h, w, 1), dtype=np.uint8) * 255
@@ -1873,9 +1876,7 @@ class TestSuite(fixtures.TestCommon):
         # Read in the image (as expected on little-endian), flip it
         # around, prepend an alpha layer, then get rid of the last layer
         # to simulate what would have happened on big-endian.
-        expected = skimage.io.imread(
-            self.astronaut_ycbcr_jpeg_tiled, plugin='pil'
-        )
+        expected = self._imread(self.astronaut_ycbcr_jpeg_tiled)
         h, w, _ = expected.shape
         expected = np.flip(expected, axis=2)
         A = np.ones((h, w, 1), dtype=np.uint8) * 255
@@ -1911,7 +1912,7 @@ class TestSuite(fixtures.TestCommon):
         # Read in the image (as expected on little-endian), flip it
         # around, prepend an alpha layer, then get rid of the last layer
         # to simulate what would have happened on big-endian.
-        expected = skimage.io.imread(self.ycbcr_stripped, plugin='pil')
+        expected = self._imread(self.ycbcr_stripped)
         h, w, _ = expected.shape
         expected = np.flip(expected, axis=2)
         A = np.ones((h, w, 1), dtype=np.uint8) * 255
@@ -1919,3 +1920,47 @@ class TestSuite(fixtures.TestCommon):
         expected = expected[:, :, :3]
 
         np.testing.assert_array_equal(actual, expected)
+
+    def test_unevenly_tiled(self):
+        """
+        SCENARIO:  Convert monochromatic TIFF file to JP2.  The TIFF is tiled
+        2x3, and the 2nd row of tiles consists of partial tiles.
+
+        EXPECTED RESULT:  The JP2 file validates
+        """
+        with Tiff2Jp2k(
+            self.moon63, self.temp_jp2_filename, tilesize=(32, 32)
+        ) as j:
+            j.run()
+
+        jp2 = Jp2k(self.temp_jp2_filename)
+        actual = jp2[:]
+        expected = self._imread(self.moon63)
+        np.testing.assert_array_equal(actual, expected)
+
+        c = jp2.get_codestream()
+        self.assertEqual(c.segment[1].xsiz, 96)
+        self.assertEqual(c.segment[1].ysiz, 63)
+        self.assertEqual(c.segment[1].xtsiz, 32)
+        self.assertEqual(c.segment[1].ytsiz, 32)
+
+    def test_issue678(self):
+        """
+        SCENARIO:  The TIFF is stripped, but has no RowsPerStrip tag.
+
+        EXPECTED RESULT:  No errors, the image data validates.
+        """
+        tfile = ir.files('tests.data.tiff').joinpath('issue678.tif')
+
+        with warnings.catch_warnings():
+
+            # Two TIFF warnings we can ignore, both due to the fact that we
+            # had to mangle an existing file to get an appropriate test file.
+            warnings.simplefilter('ignore')
+            with Tiff2Jp2k(tfile, self.temp_jp2_filename) as j:
+                j.run()
+
+        jp2 = Jp2k(self.temp_jp2_filename)
+        actual = jp2[:]
+        expected = self._imread(tfile)
+        np.testing.assert_array_equal(actual, expected)
